Class: PostgresUpsert::TableWriter
- Defined in:
- lib/postgres_upsert/table_writer.rb
Overview
alternate version of PostgresUpsert::Writer which does not rely on AR table information.
We can use this model to upsert data into views, or tables not associated to rails models
Instance Method Summary collapse
-
#initialize(table_name, source, options = {}) ⇒ TableWriter
constructor
A new instance of TableWriter.
Methods inherited from Writer
Constructor Details
#initialize(table_name, source, options = {}) ⇒ TableWriter
Returns a new instance of TableWriter.
5 6 7 8 |
# File 'lib/postgres_upsert/table_writer.rb', line 5 def initialize(table_name, source, = {}) @table_name = table_name super(nil, source, ) end |